@@ -1,6 +1,6 @@
 use std::fmt;
 
-use crate::util::{Zone, auto_display};
+use crate::util::Zone;
 
 #[derive(Debug, PartialEq, Eq, Hash, Clone, Copy)]
 pub enum SysMessage {
@@ -31,8 +31,10 @@ impl SysMessage {
 impl fmt::Display for SysMessage {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         match self {
-            SysMessage::MapRelicList(zone) => write!(f, "{} {}", zone, auto_display(self)),
-            _ => write!(f, "{}", auto_display(self)),
+            SysMessage::RelicList => write!(f, "Relic List"),
+            SysMessage::MapRelicList(zone) => write!(f, "{zone} Map Relic List"),
+            SysMessage::PickupCount => write!(f, "Pickup Count"),
+            SysMessage::GoalProgress => write!(f, "Goal Progress"),
         }
     }
 }
